#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec-vm
Version:	4.2.20
Release:	1%{dist}
Summary:	The Qubes qrexec files (qube side)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:	pam-devel
BuildRequires:	pandoc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-core-qrexec-devel
BuildRequires:	lsb-core-noarch
BuildRequires:	systemd-devel

Requires:   python%{python3_pkgversion}
Requires:   qubes-core-qrexec = %{version}-%{release}
# The library is backwards compatible (new library works with old programs)
# but not forwards compatible (old library does not work with new programs)
Requires:   qubes-core-qrexec-libs >= %{version}-%{release}

Provides:   qubes-core-agent-qrexec = 4.1.0-1
Obsoletes:  qubes-core-agent-qrexec < 4.1.0-1

Source0: qubes-core-qrexec-%{version}.tar.gz

Requires: (%{name}-selinux if selinux-policy)

%package selinux
BuildRequires: selinux-policy
BuildRequires: selinux-policy-devel
%{?selinux_requires}
Requires(post): qubes-core-agent-selinux
Summary: SELinux policies for qrexec
License: GPLv2+

%description selinux
The SELinux policies for qrexec.  You need this package if you want to have
SELinux enforcing in a qube.

%description
The Qubes qrexec files for installation on a qube.

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
make all-vm all-vm-selinux
#make -C doc PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} man

%install
make install-vm install-vm-selinux \
    DESTDIR=$RPM_BUILD_ROOT \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    SYSCONFDIR=%{_sysconfdir}

#make -C doc DESTDIR=$RPM_BUILD_ROOT \
#    PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} \
#    install

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%post
%systemd_post qubes-qrexec-agent.service

%preun
%systemd_preun qubes-qrexec-agent.service

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/qubes-core-qrexec.pp || :

%postun selinux
if [ "$1" -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/qubes-core-qrexec.pp
fi || :

%posttrans selinux
%selinux_relabel_post
exit 0

%posttrans
# when upgrading from R4.0, %%postun of qubes-core-agent-qrexec will revert
# %%post of this package. Redo the action in %%posttrans
%systemd_post qubes-qrexec-agent.service
# and then start it back
if systemctl is-enabled qubes-qrexec-agent.service >/dev/null 2>&1; then
    systemctl start qubes-qrexec-agent.service
fi

%files
%defattr(-,root,root,-)
%config(noreplace) /etc/pam.d/qrexec
%dir /etc/qubes
%dir /etc/qubes/rpc-config
/etc/qubes/rpc-config/README

%{_bindir}/qrexec-client-vm
%{_bindir}/qrexec-fork-server

%{_mandir}/man1/qrexec-client-vm.1*

%dir /usr/lib/qubes
/usr/lib/qubes/qrexec-agent
/usr/lib/qubes/qrexec-client-vm
/usr/lib/qubes/qrexec_client_vm
/lib/systemd/system/qubes-qrexec-agent.service

%files selinux
%{_datadir}/selinux/devel/include/contrib/ipp-qubes-core-qrexec.if
%{_datadir}/selinux/packages/qubes-core-qrexec.pp

%changelog
* Fri Jun 14 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec

* Fri Jun 14 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7a2155d
- version 4.2.20

* Wed Jun 12 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bab74d5
- Downgrade errors about incompatible service config to warnings

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 2b71adb
- Avoid closing stderr when MSG_DATA_EXIT_CODE is received

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0701529
- Send EOF whenever closing stdout

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 50bc9db
- Send EOF on stdout when exiting due to EOF on stdin

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 3658079
- Always send EOF on stderr

* Wed May 22 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c0f4d28
- Command and API documentation

* Sat May 18 2024 Ben Grande <ben.grande.b@gmail.com> - 5ced777
- Document rpc config until exit-on-server-eof

* Fri May 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 110f840
- Mute pylint false positive

* Thu May 16 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 49f9710
- qrexec-daemon: Use close_range where possible

* Thu May 09 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43f49f0
- version 4.2.19

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 64d6e06
- Test if a service config directory itself is invalid

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c6f9a2f
- Fail early if the service config cannot be found

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9114fb3
- Avoid passing stderr_fd to handle_data_client

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8b683a8
- tests: do not write to maybe-closed socket

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a60c40c
- Add support for exiting on client or service EOF

* Sun May 05 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 129b5dd
- Better logging for socket services

* Sat May 04 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - cdf92b7
- Check at startup that standard streams are open

* Thu May 02 2024 Ben Grande <ben.grande.b@gmail.com> - 19ed045
- Document rpc-config until skip-service-descriptor

* Thu May 02 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9e72d82
- Fix SIGUSR1 after stdin_fd closed

* Wed May 01 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adbf4a2
- Fix build error on redefined _FORTIFY_SOURCE

* Wed May 01 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8f2539a
- Explain why there is no use after free vulnerability

* Wed May 01 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6d37768
- Restore correct log path

* Wed May 01 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0fcec31
- Ensure proper RPM dependency ordering

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c2f197c
- Ensure that EOF is propagated to stdout

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 8120940
- Document the file descriptrs for struct process_io_request

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a3bbcb5
- Prefer close() to shutdown()

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - bc71817
- do_fork_exec(): Drop status pipe

* Tue Apr 30 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - acda549
- Use close_range() instead of close loop

* Mon Apr 29 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - d9e3a76
- fix_fds(): check that input FDs are okay

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 2844865
- Fix memory leak in load_service_config()

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - c801cf3
- Refuse executable service with skip-service-descriptor=true

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - b355ccc
- Forbide skip-service-descriptor=true with explicit username

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 873e77e
- If skip-service-descriptor=true, do not use fork server

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 76790cb
- Avoid leaking vchans

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e06514b
- Share qrexec-daemon VM -> VM call code with qrexec-client

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0f7bf45
- Avoid warnings from pytest

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 6fa1106
- Adjust test to reflect reality

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 56fdd7d
- Eradicate VLAs from the codebase

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 82cbe71
- Use calloc() instead of malloc() + memset()

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 696f831
- Avoid pointlessly setting argv[0]

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 930b47d
- Add visibility attributes and use -fvisibility=hidden

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - b8f0031
- Avoid allocating a big buffer for each loop iteration

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 57855c6
- qrexec-daemon: check for valid messages from clients

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 4f1e524
- qrexec-daemon: Do not check service identifier for DEFAULT: keyword

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e98ed7a
- qrexec-agent: Take advantage of flexible array members

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 3313110
- qrexec-daemon: Take advantage of flexible array members

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - e33f334
- qrexec-daemon: partially validate messages from client

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - ad72712
- Check for empty source domain names

* Sun Apr 28 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 71c1ae3
- Ensure consistent treatment of "QUBESRPC" followed by non-space

